@@ -16,11 +16,13 @@ from itertools import chain
 import shutil
 import nox
 
-nox.options.sessions = ['test-2.7', 'test-3.7', 'test-pypy', 'test-pypy3']
-default_py = '3.7'
+_PY_VERSIONS = ('2.7', '3.7', '3.8', '3.9', '3.10', 'pypy', 'pypy3')
+_PY_DEFAULT_VERSION = '3.9'
+
+nox.options.sessions = ['test-2.7', 'test-{}'.format(_PY_DEFAULT_VERSION), 'test-pypy', 'test-pypy3']
 
 
-@nox.session(python=['2.7', '3.7', '3.8', '3.9', 'pypy', 'pypy3'])
+@nox.session(python=_PY_VERSIONS)
 def test(session):
     """\
     Run test suite.
@@ -38,7 +40,7 @@ def test(session):
     session.run('py.test')
 
 
-@nox.session(python=default_py)
+@nox.session(python=_PY_DEFAULT_VERSION)
 def docs(session):
     """\
     Build the documentation.
@@ -60,7 +62,7 @@ def docs(session):
         session.log("'man/segno.1' has been modified, don't forget to commit")
 
 
-@nox.session(python=default_py)
+@nox.session(python=_PY_DEFAULT_VERSION)
 def coverage(session):
     """\
     Run coverage.
@@ -75,7 +77,7 @@ def coverage(session):
     cover('html', '-d', output_dir)
 
 
-@nox.session(python=default_py)
+@nox.session(python=_PY_DEFAULT_VERSION)
 def lint(session):
     """\
     Run flake8
@@ -86,7 +88,7 @@ def lint(session):
     session.run('flake8', 'tests/')
 
 
-@nox.session(python=default_py)
+@nox.session(python=_PY_DEFAULT_VERSION)
 def benchmarks(session):
     """\
     Run the benchmarks and create the charts.
@@ -109,7 +111,7 @@ def benchmarks(session):
 #
 
 
-@nox.session(name='start-release', python=default_py)
+@nox.session(name='start-release', python=_PY_DEFAULT_VERSION)
 def start_release(session):
     """\
     Prepares a release.
@@ -137,7 +139,7 @@ def start_release(session):
     session.log('When done, call nox -e finish-release -- {}'.format(version))
 
 
-@nox.session(name='finish-release', python=default_py)
+@nox.session(name='finish-release', python=_PY_DEFAULT_VERSION)
 def finish_release(session):
     """\
     Finishes the release.
@@ -163,23 +165,23 @@ def finish_release(session):
                 'nox -e build-release -- {} / nox -e upload-release'.format(version))
 
 
-@nox.session(name='build-release', python=default_py)
+@nox.session(name='build-release', python=_PY_DEFAULT_VERSION)
 def build_release(session):
     """\
     Builds a release: Creates sdist and wheel
     """
     version = _validate_version(session)
+    session.install('build', 'wheel')
     git = partial(session.run, 'git', external=True)
     git('fetch')
     git('fetch', '--tags')
     git('checkout', version)
-    session.install('setuptools', 'wheel')
     shutil.rmtree('dist', ignore_errors=True)
-    session.run('python', 'setup.py', 'sdist', 'bdist_wheel')
+    session.run('python', '-m', 'build', '--no-isolation')
     git('checkout', 'master')
 
 
-@nox.session(name='upload-release', python=default_py)
+@nox.session(name='upload-release', python=_PY_DEFAULT_VERSION)
 def upload_release(session):
     """\
     Uploads a release to PyPI
