@@ -21,7 +21,7 @@ try:  # pragma: no cover
 except NameError:  # pragma: no cover
     str_type = str
 
-__version__ = '1.4.0'
+__version__ = '1.4.1'
 
 __all__ = ('make', 'make_qr', 'make_micro', 'make_sequence', 'QRCode',
            'QRCodeSequence', 'DataOverflowError')
@@ -101,7 +101,7 @@ def make(content, error=None, version=None, mode=None, mask=None, encoding=None,
                 user::
 
                     import segno
-                    qr = segno.make('书读百遍其义自现', mode='hanzi')
+                    qrcode = segno.make('书读百遍其义自现', mode='hanzi')
 
     :type mode: str or None
     :param mask: Data mask. If the value is ``None`` (default), the
@@ -348,11 +348,11 @@ class QRCode:
         False = light module)::
 
             >>> import segno
-            >>> qr = segno.make('The Beatles')
-            >>> width, height = qr.symbol_size(scale=2)
+            >>> qrcode = segno.make('The Beatles')
+            >>> width, height = qrcode.symbol_size(scale=2)
             >>> res = []
             >>> # Scaling factor 2, default border
-            >>> for row in qr.matrix_iter(scale=2):
+            >>> for row in qrcode.matrix_iter(scale=2):
             >>>     res.append([col == 0x1 for col in row])
             >>> width == len(res[0])
             True
@@ -493,10 +493,15 @@ class QRCode:
         This method returns a string that can be used in an HTML context.
 
         This method uses the same parameters as the usual SVG serializer, see
-        :py:func:`save` and the available `SVG parameters <#svg>`_
+        :py:func:`save` and the available `SVG parameters <#svg>`_ (the ``out``
+        and ``kind`` parameters are not supported).
 
-        The returned string can be used directly in Jinja / Django templates,
-        provided the ``safe`` filter is used::
+        The returned string can be used directly in
+        `Jinja <https://jinja.palletsprojects.com/>`_ and
+        `Django <https://www.djangoproject.com/>`_ templates, provided the
+        ``safe`` filter is used which marks a string as not requiring further
+        HTML escaping prior to output.
+        ::
 
             <div>{{ qr.svg_inline(dark='#228b22', scale=3) | safe }}</div>
 
@@ -563,7 +568,7 @@ class QRCode:
         scale         Integer or float indicating the size of a single module.
                       Default: 1. The interpretation of the scaling factor depends
                       on the serializer. For pixel-based output (like :ref:`PNG <png>`)
-                      the scaling factor is interepreted as pixel-size (1 = 1 pixel).
+                      the scaling factor is interpreted as pixel-size (1 = 1 pixel).
                       :ref:`EPS <eps>` interprets ``1`` as 1 point (1/72 inch) per
                       module.
                       Some serializers (like :ref:`SVG <svg>`) accept float values.
@@ -924,6 +929,7 @@ class QRCode:
         kind             "xpm"
         scale            integer
         dark             Default: "#000" (black).
+                         ``None`` indicates transparent dark modules.
         light            Default value "#fff" (white)
                          ``None`` indicates transparent light modules.
         name             Name of the variable (default: "img")
