@@ -14,7 +14,8 @@ import io
 import segno
 try:
     from .tutils import matrix_looks_valid
-except (ValueError, SystemError, ImportError):  # Attempted relative import in non-package
+# Attempted relative import in non-package
+except (ValueError, SystemError, ImportError):
     from tutils import matrix_looks_valid
 
 
