@@ -34,7 +34,8 @@ def txt_as_matrix(buff, border):
     code = buff.getvalue().splitlines()
     len_without_border = len(code) - border
     for line in islice(code, border, len_without_border):
-        res.append([int(clr) for clr in islice(line, border, len_without_border)])
+        res.append([int(clr) for clr in islice(line, border,
+                                               len_without_border)])
     return res
 
 
